@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -66,6 +66,7 @@ use vars qw($BasePath
  $BinPath
  $SbinPath
  $VarPath
+ $FontPath
  $LexiconPath
  $StaticPath
  $PluginPath
@@ -199,7 +200,7 @@ sub Init {
     _BuildTableAttributes();
     RT::I18N->Init;
     RT->Config->PostLoadCheck;
-    RT::Lifecycle->new->FillCache;
+    RT::Lifecycle->FillCache;
 }
 
 =head2 ConnectToDatabase
@@ -786,7 +787,7 @@ sub CanonicalizeGeneratedPaths {
 
         for my $path (
                     qw/EtcPath BinPath SbinPath VarPath LocalPath StaticPath LocalEtcPath
-                    LocalLibPath LexiconPath LocalLexiconPath PluginPath
+                    LocalLibPath LexiconPath LocalLexiconPath PluginPath FontPath
                     LocalPluginPath LocalStaticPath MasonComponentRoot MasonLocalComponentRoot
                     MasonDataDir MasonSessionDir/
                      )
