@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -248,8 +248,9 @@ sub PushBasics {
     my $cfs = RT::CustomFields->new( RT->SystemUser );
     $cfs->Limit(
         FIELD => 'LookupType',
-        VALUE => $_
-    ) for qw/RT::User RT::Group RT::Queue/;
+        OPERATOR => 'IN',
+        VALUE => [ qw/RT::User RT::Group RT::Queue/ ],
+    );
     $self->PushObj( $cfs );
 
     # Global attributes
@@ -362,12 +363,16 @@ sub Process {
         @_
     );
 
-    my $uid = $args{object}->UID;
+    my $obj = $args{object};
+    my $uid = $obj->UID;
 
-    # Skip all dependency walking if we're cloning.  Marking UIDs as seen
-    # forces them to be visited immediately.
-    $self->{seen}{$uid}++
-        if $self->{Clone} and $uid;
+    # Skip all dependency walking if we're cloning; go straight to
+    # visiting them.
+    if ($self->{Clone} and $uid) {
+        return if $obj->isa("RT::System");
+        $self->{progress}->($obj) if $self->{progress};
+        return $self->Visit(%args);
+    }
 
     return $self->SUPER::Process( @_ );
 }
@@ -398,7 +403,7 @@ sub Observe {
         return $self->{FollowTickets};
     } elsif ($obj->isa("RT::ACE")) {
         return $self->{FollowACL};
-    } elsif ($obj->isa("RT::Scrip") or $obj->isa("RT::Template")) {
+    } elsif ($obj->isa("RT::Scrip") or $obj->isa("RT::Template") or $obj->isa("RT::ObjectScrip")) {
         return $self->{FollowScrips};
     } elsif ($obj->isa("RT::GroupMember")) {
         my $grp = $obj->GroupObj->Object;
