@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -71,7 +71,9 @@ sub LabelValue {
     my $raw = $self->RawValue( $name, @_ );
 
     if ( my $code = $self->Report->LabelValueCode( $name ) ) {
-        return $code->( $self, %{ $self->Report->ColumnInfo( $name ) }, VALUE => $raw );
+        $raw = $code->( $self, %{ $self->Report->ColumnInfo( $name ) }, VALUE => $raw );
+        return $self->loc('(no value)') unless defined $raw && length $raw;
+        return $raw;
     }
 
     unless ( ref $raw ) {
