@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -1111,28 +1111,48 @@ sub FindDependencies {
 
     $self->SUPER::FindDependencies($walker, $deps);
 
+    my $applied = RT::ObjectScrips->new( $self->CurrentUser );
+    $applied->LimitToScrip( $self->id );
+    $deps->Add( in => $applied );
+
     $deps->Add( out => $self->ScripConditionObj );
     $deps->Add( out => $self->ScripActionObj );
-    $deps->Add( out => $self->QueueObj ) if $self->QueueObj->Id;
     $deps->Add( out => $self->TemplateObj );
 }
 
-sub PreInflate {
-    my $class = shift;
-    my ($importer, $uid, $data) = @_;
+sub __DependsOn {
+    my $self = shift;
+    my %args = (
+        Shredder => undef,
+        Dependencies => undef,
+        @_,
+    );
+    my $deps = $args{'Dependencies'};
+    my $list = [];
 
-    $class->SUPER::PreInflate( $importer, $uid, $data );
+    my $objs = RT::ObjectScrips->new( $self->CurrentUser );
+    $objs->LimitToScrip( $self->Id );
+    push @$list, $objs;
 
-    if ($data->{Queue} == 0) {
-        my $obj = RT::Scrip->new( RT->SystemUser );
-        $obj->LoadByCols( Queue => 0, Description => $data->{Description} );
-        if ($obj->Id) {
-            $importer->Resolve( $uid => ref($obj) => $obj->Id );
-            return;
-        }
-    }
+    $deps->_PushDependencies(
+        BaseObject    => $self,
+        Flags         => RT::Shredder::Constants::DEPENDS_ON,
+        TargetObjects => $list,
+        Shredder      => $args{'Shredder'}
+    );
 
-    return 1;
+    return $self->SUPER::__DependsOn( %args );
+}
+
+sub Serialize {
+    my $self = shift;
+    my %args = (@_);
+    my %store = $self->SUPER::Serialize(@_);
+
+    # Store the string, not a reference to the object
+    $store{Template} = $self->Template;
+
+    return %store;
 }
 
 RT::Base->_ImportOverlays();
