@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -245,7 +245,7 @@ sub GuessType {
 sub HandleDefault   {
     my $fts = RT->Config->Get('FullTextSearch');
     if ($fts->{Enable} and $fts->{Indexed}) {
-        return default => "(Subject LIKE '$_[1]' OR Content LIKE '$_[1]')";
+        return default => "Content LIKE '$_[1]'";
     } else {
         return default => "Subject LIKE '$_[1]'";
     }
