@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -51,15 +51,13 @@ package RT::Shredder::Constants;
 use strict;
 use warnings;
 
-use base qw(Exporter);
-
 =head1 NAME
 
 RT::Shredder::Constants -  RT::Shredder constants that is used to mark state of RT objects.
 
 =head1 DESCRIPTION
 
-This module exports two group of bit constants.
+This module contains two group of bit constants.
 First group is group of flags which are used to clarify dependecies between objects, and
 second group is states of RT objects in Shredder cache.
 
@@ -87,9 +85,9 @@ change this reference when we delete user.
 =cut
 
 use constant {
-    DEPENDS_ON    => 0x000001,
-    WIPE_AFTER    => 0x000010,
-    VARIABLE    => 0x001000,
+    DEPENDS_ON => 0x001,
+    WIPE_AFTER => 0x002,
+    VARIABLE   => 0x004,
 };
 
 =head1 STATES
@@ -108,18 +106,9 @@ delete query is called once.
 =cut
 
 use constant {
-    ON_STACK    => 0x00000,
-    IN_WIPING    => 0x00001,
-    WIPED        => 0x00010,
+    ON_STACK  => 0x000,
+    IN_WIPING => 0x010,
+    WIPED     => 0x020,
 };
 
-our @EXPORT = qw(
-        DEPENDS_ON
-        WIPE_AFTER
-        VARIABLE
-        ON_STACK
-        IN_WIPING
-        WIPED
-        );
-
 1;
