@@ -2,7 +2,7 @@
 #
 # COPYRIGHT:
 #
-# This software is Copyright (c) 1996-2014 Best Practical Solutions, LLC
+# This software is Copyright (c) 1996-2015 Best Practical Solutions, LLC
 #                                          <sales@bestpractical.com>
 #
 # (Except where explicitly superseded by other copyright notices)
@@ -117,7 +117,7 @@ sub AvailableRights {
     if ($principal and $principal->IsRoleGroup) {
         my $role = $principal->Object->Name;
         for my $class (keys %RT::ACE::RIGHTS) {
-            next unless $class->DOES('RT::Record::Role::Roles') and $class->HasRole($role);
+            next unless $class->DOES('RT::Record::Role::Roles') and $class->HasRole($role) and $class ne "RT::System";
             push @rights, values %{ $RT::ACE::RIGHTS{$class} };
         }
     } else {
